
Effectful Pythonic Parsers
==========================

Welcome to the home of EPP library, which provides a way to combine basic
parsers and effects to build complex parsers that transform text into something
more useful.

For a quick introduction into using the library, see ``quickstart.rst`` in the
``docs`` directory. If you find that a certain parser should be written
directly, and not as a combination of existing ones, see ``writing_parsers.rst``
in the same directory (and if it's something that makes sense to be included in
the library proper, file a pull request!). Finally, ``core.rst`` and
``parsers.rst`` provide full documentation of existing parsers in the ``core``
and ``parsers`` module respectively (you shouldn't care much which parser
belongs where, it's just to keep bookkeeping parsers separated from those doing
actual parsing).
